import resizeSensor from 'vue-resize-sensor'

export default function(pdfjsWrapper) {

    var createLoadingTask = pdfjsWrapper.createLoadingTask;
    var PDFJSWrapper = pdfjsWrapper.PDFJSWrapper;

    return {
        createLoadingTask: createLoadingTask,
        render: function(h) {
            return h('div', {
                attrs: {
                    style: 'position: relative'
                }
            }, [
                h('div', {
                    ref: 'canvasParent',
                    style: {
                        'display': 'flex',
                        'justify-content': 'center'
                    }
                }, [

                ]),
                h('div', {
                    class: 'annotationLayer',
                    ref: 'annotationLayer'
                }),
                h(resizeSensor, {
                    props: {
                        initial: true
                    },
                    on: {
                        resize: this.resize
                    },
                })
            ])
        },
        props: {
            src: {
                type: [String, Object],
                default: '',
            },
            container: {
                type: String
            },
            page: {
                type: Number,
                default: 1,
            },
            rotate: {
                type: Number,
                default: 0,
            },
        },
        watch: {
            src: function() {

                this.pdf.loadDocument(this.src);
            },
            page: function() {

                this.pdf.loadPage(this.page, this.rotate);
            },
            rotate: function() {
                this.pdf.renderPage(this.rotate);
            },
        },
        methods: {
            resize: function(size) {

                let width = document.getElementById(this.container).offsetWidth;
                let height = document.getElementById(this.container).offsetHeight;
                // check if the element is attached to the dom tree || resizeSensor being destroyed
                if (this.$el.parentNode === null || (size.width === 0 && size.height === 0))
                    return;
                let calHeight = width * (this.pdf.getCanvas().height / this.pdf.getCanvas().width);
                if (calHeight > height) {
                    calHeight = height;
                }

                // on IE10- canvas height must be set
                this.pdf.setCanvasHeight(calHeight + 'px');
                // update the page when the resolution is too poor
                var resolutionScale = this.pdf.getResolutionScale();
                this.pdf.renderPage(this.rotate);



                //this.$refs.annotationLayer.style.transform = 'scale(' + resolutionScale + ')';
            },
            print: function(dpi, pageList) {

                this.pdf.printPage(dpi, pageList);
            }
        },

        // doc: mounted hook is not called during server-side rendering.
        mounted: function() {

            this.pdf = new PDFJSWrapper(this.$refs.canvasParent, this.$refs.annotationLayer, this.$emit.bind(this), this.container);

            this.$on('loaded', function() {
                //let docheight = document.getElementById(this.container).offsetHeight;
                //this.pdf.setCanvasHeight(docheight + 'px');
                this.pdf.loadPage(this.page, this.rotate);
            });

            this.$on('page-size', function(width, height) {
                //设置页面的大小
                //let width = document.getElementById(this.container).offsetWidth;
                //let docheight = document.getElementById(this.container).offsetHeight;
                //let docWidth = document.getElementById(this.container).offsetWidth;
                //let calHeight = docWidth * (this.pdf.getCanvas().height / this.pdf.getCanvas().width);
                //if (calHeight > docheight) {
                // calHeight = docheight;
                //}

                this.pdf.setCanvasHeight(this.pdf.getCanvas().offsetWidth * (height / width) + 'px');
            });

            //初始设置高度
            let docheight = document.getElementById(this.container).offsetHeight;
            console.log("-------获取的高度----------");
            console.log(docheight);
            this.pdf.setCanvasHeight(docheight + "px");
            this.pdf.loadDocument(this.src);
        },

        // doc: destroyed hook is not called during server-side rendering.
        destroyed: function() {

            this.pdf.destroy();
        }
    }

}